==> chemistry-opencmis-client-impl-0.3.0-sources.jar: org/apache/chemistry/opencmis/client/runtime/PolicyImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.chemistry.opencmis.client.runtime;

import org.apache.chemistry.opencmis.client.api.ObjectType;
import org.apache.chemistry.opencmis.client.api.OperationContext;
import org.apache.chemistry.opencmis.client.api.Policy;
import org.apache.chemistry.opencmis.client.api.TransientCmisObject;
import org.apache.chemistry.opencmis.client.api.TransientPolicy;
import org.apache.chemistry.opencmis.commons.PropertyIds;
import org.apache.chemistry.opencmis.commons.data.ObjectData;

public class PolicyImpl extends AbstractFilableCmisObject implements Policy {

    private static final long serialVersionUID = 1L;

    /**
     * Constructor.
     */
    public PolicyImpl(SessionImpl session, ObjectType objectType, ObjectData objectData, OperationContext context) {
        initialize(session, objectType, objectData, context);
    }

    @Override
    protected TransientCmisObject createTransientCmisObject() {
        TransientPolicyImpl tp = new TransientPolicyImpl();
        tp.initialize(getSession(), this);

        return tp;
    }

    public TransientPolicy getTransientPolicy() {
        return (TransientPolicy) getTransientObject();
    }

    public String getPolicyText() {
        return getPropertyValue(PropertyIds.POLICY_TEXT);
    }

}

==> chemistry-opencmis-client-impl-0.10.0-sources.jar: org/apache/chemistry/opencmis/client/runtime/PolicyImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.chemistry.opencmis.client.runtime;

import org.apache.chemistry.opencmis.client.api.ObjectType;
import org.apache.chemistry.opencmis.client.api.OperationContext;
import org.apache.chemistry.opencmis.client.api.Policy;
import org.apache.chemistry.opencmis.commons.PropertyIds;
import org.apache.chemistry.opencmis.commons.data.ObjectData;

public class PolicyImpl extends AbstractFilableCmisObject implements Policy {

    private static final long serialVersionUID = 1L;

    /**
     * Constructor.
     */
    public PolicyImpl(SessionImpl session, ObjectType objectType, ObjectData objectData, OperationContext context) {
        initialize(session, objectType, objectData, context);
    }

    /**
     * @deprecated Support for transient objects will be removed in the future.
     */
    @Deprecated
    @Override
    protected org.apache.chemistry.opencmis.client.api.TransientCmisObject createTransientCmisObject() {
        TransientPolicyImpl tp = new TransientPolicyImpl();
        tp.initialize(getSession(), this);

        return tp;
    }

    /**
     * @deprecated Support for transient objects will be removed in the future.
     */
    @Deprecated
    public org.apache.chemistry.opencmis.client.api.TransientPolicy getTransientPolicy() {
        return (org.apache.chemistry.opencmis.client.api.TransientPolicy) getTransientObject();
    }

    public String getPolicyText() {
        return getPropertyValue(PropertyIds.POLICY_TEXT);
    }

}
